#include "cylinderview.h"

#include <Qt3D/qglbuilder.h>
#include <Qt3D/qglcylinder.h>
#include <Qt3D/qgldome.h>

CylinderView::CylinderView(QWidget *parent)
    : QGLView(parent)
    , cylinder(new QGLSceneNode(this))
{
    QGLBuilder builder;
    QGLSceneNode *root = builder.sceneNode();

    QGLMaterial *coneMaterial = new QGLMaterial;
    coneMaterial->setAmbientColor(Qt::gray);
    coneMaterial->setDiffuseColor(Qt::gray);
    QUrl urlLid;
    urlLid.setPath(QLatin1String(":/only_cone1_mod.jpg"));
    urlLid.setScheme(QLatin1String("file"));
    coneMaterial->setTextureUrl(urlLid);
    int coneMat = root->palette()->addMaterial(coneMaterial);

    //builder.newNode()->setObjectName(QLatin1String("cone"));
    QGLCylinder myCylinder (0.75, 0.15, 0.75, 36, 25, true, true);
    myCylinder.setBaseEnabled(false);
    myCylinder.setTopEnabled(false);
    builder << myCylinder;
    //builder.currentNode()->setMaterialIndex(coneMat);
    //builder.currentNode()->setEffect(QGL::LitDecalTexture2D);
    QGLSceneNode *cone = builder.currentNode();
    cone->setObjectName("cone");
    //root->addNode(cone);

    QGLMaterial *domeMaterial = new QGLMaterial;
    QUrl url;
    url.setPath(QLatin1String(":/icecream1_mod.jpg"));
    url.setScheme(QLatin1String("file"));
    domeMaterial->setTextureUrl(url);
    int domeMat = root->palette()->addMaterial(domeMaterial);

    //builder.newNode()->setObjectName(QLatin1String("dome"));
    QGLDome myDome(0.75,4);
    myDome.setBaseEnabled(false);
    builder << myDome;
    //builder.currentNode()->setMaterialIndex(domeMat);
   // builder.currentNode()->setEffect(QGL::LitDecalTexture2D);
    QGLSceneNode *dome = builder.currentNode();
    dome->setObjectName("dome");
    dome->setMaterialIndex(domeMat);


    //cone->addNode(dome);

    dome->setPosition(QVector3D(0,0.0,0.75));
    //cone->setPosition(QVector3D(0,0,-0.75));

    cylinder = builder.finalizedSceneNode();
    cylinder->setParent(this);

    cylinder->setMaterialIndex(coneMat);
    cylinder->setEffect(QGL::LitDecalTexture2D);

    QMatrix4x4 m;
    m.rotate(-90.0f, 1.0f, 0.0f,0.0f);
    cylinder->setLocalTransform(m);

    qDumpScene(cylinder);
}

CylinderView::~CylinderView()
{

}

void CylinderView::paintGL(QGLPainter *painter)
{
    glClearColor(1.0f, 0.0f, 0.0f, 1.0f);
    glClear(GL_COLOR_BUFFER_BIT );
    cylinder->draw(painter);
}
